@@ -9,12 +9,12 @@ app = Flask(__name__)
 
 @app.errorhandler(404)
 def page_not_found(e):
-    return render_template('404.html'), 404
+    return "Resource not found", 404
 
 
 @app.errorhandler(500)
 def internal_error(e):
-    return render_template('500.html'), 500
+    return "Application error", 500
 
 
 @app.route("/upload", methods=["POST"])
