@@ -21,4 +21,4 @@ if __name__ == "__main__":
     args = docopt(__doc__, version='Brightway2 Reports Server 0.1')
     port = int(args.get("--port", False) or 8000)
     report_server.config['DATA_DIR'] = args["<data_dir>"]
-    run_simple("0.0.0.0", port, report_server, use_evalex=True)
+    run_simple("0.0.0.0", port, report_server)
